referrerpolicy=no-referrer-when-downgrade

RingBuildingPeopleLimit

Type Alias RingBuildingPeopleLimit 

pub type RingBuildingPeopleLimit<T: Config> = StorageValue<_GeneratedPrefixForStorageRingBuildingPeopleLimit<T>, u32, OptionQuery>;
Hint for the maximum number of people that can be included in a ring through a single root building call. If no value is set, then the onboarding size will be used instead.

Storage type is [StorageValue] with value type u32.

Aliased Type

pub struct RingBuildingPeopleLimit<T: Config>(/* private fields */);